summaryrefslogtreecommitdiffstats
path: root/kopete/kopete/config/identity/globalidentitiesmanager.h
diff options
context:
space:
mode:
Diffstat (limited to 'kopete/kopete/config/identity/globalidentitiesmanager.h')
-rw-r--r--kopete/kopete/config/identity/globalidentitiesmanager.h26
1 files changed, 13 insertions, 13 deletions
diff --git a/kopete/kopete/config/identity/globalidentitiesmanager.h b/kopete/kopete/config/identity/globalidentitiesmanager.h
index c188d497..71e890b0 100644
--- a/kopete/kopete/config/identity/globalidentitiesmanager.h
+++ b/kopete/kopete/config/identity/globalidentitiesmanager.h
@@ -18,8 +18,8 @@
#ifndef GLOBALIDENTITIESMANAGER_H
#define GLOBALIDENTITIESMANAGER_H
-#include <qobject.h>
-#include <qmap.h>
+#include <tqobject.h>
+#include <tqmap.h>
namespace Kopete
{
@@ -54,7 +54,7 @@ public:
/**
* @brief Create a new identity and add it to the internal list.
*/
- void createNewIdentity(const QString &identityName);
+ void createNewIdentity(const TQString &identityName);
/**
* @brief Copy a identity
@@ -62,7 +62,7 @@ public:
* @param copyIdentityName Name for the copy identity.
* @param sourceIdentity Name of the source identity.
*/
- void copyIdentity(const QString &copyIdentityName, const QString &sourceIdentity);
+ void copyIdentity(const TQString &copyIdentityName, const TQString &sourceIdentity);
/**
* @brief Rename a identity
@@ -70,14 +70,14 @@ public:
* @param oldName Identity to rename.
* @param newName New identity name.
*/
- void renameIdentity(const QString &oldName, const QString &newName);
+ void renameIdentity(const TQString &oldName, const TQString &newName);
/**
* @brief Delete identity
*
* @param removedIdentity Identity name to remove.
*/
- void removeIdentity(const QString &removedIdentity);
+ void removeIdentity(const TQString &removedIdentity);
/**
* @brief Update the specified identity using the source MetaContact
@@ -85,7 +85,7 @@ public:
* @param updatedIdentity Identity to update.
* @param sourceMetaContact Source of data.
*/
- void updateIdentity(const QString &updatedIdentity, Kopete::MetaContact *sourceMetaContact);
+ void updateIdentity(const TQString &updatedIdentity, Kopete::MetaContact *sourceMetaContact);
/**
* @brief Check if the specified identityName exists.
@@ -93,7 +93,7 @@ public:
* This is a helper method to avoid duplicated entries.
* @return if the identityName is in the internal list.
*/
- bool isIdentityPresent(const QString &identityName);
+ bool isIdentityPresent(const TQString &identityName);
/**
* @brief Return the specified identity.
@@ -101,7 +101,7 @@ public:
* @param identityName Identity to retrive.
* @return Identity data as Kopete::MetaContact.
*/
- Kopete::MetaContact *getIdentity(const QString &identityName);
+ Kopete::MetaContact *getIdentity(const TQString &identityName);
/**
* @brief Load the XML file where global identities metacontacts are stored.
@@ -117,17 +117,17 @@ public:
* @brief Return the list of global identities metacontact.
* @return The pointer list of metacontact as QValueList
*/
- QMap<QString, Kopete::MetaContact*> getGlobalIdentitiesList();
+ TQMap<TQString, Kopete::MetaContact*> getGlobalIdentitiesList();
private:
- GlobalIdentitiesManager(QObject *parent = 0, const char *name = 0);
+ GlobalIdentitiesManager(TQObject *parent = 0, const char *name = 0);
/**
* @brief Return a XML representation of the global identities list.
*
* @return the XML represention as QDomDocument.
*/
- const QDomDocument toXML();
+ const TQDomDocument toXML();
Kopete::MetaContact *createNewMetaContact();
Kopete::MetaContact *createCopyMetaContact(Kopete::MetaContact *source);
@@ -117,17 +117,17 @@ public:
* @brief Return a XML representation of the global identities list.
*
- * @return the XML represention as QDomDocument.
+ * @return the XML represention as TQDomDocument.
*/